##  Types of Connections Between Fact Sheets
The types of connections that one can establish between fact sheets will depend on the types of fact sheets that they are trying to connect.
Listed below are some examples of the types of relations that can be established when joining different types of fact sheets:
Connecting Business Capabilities with Applications:
  * Requires
  * Requires by
  * Business Capability to Application


Connecting Business Capabilities with Organizations:
  * Requires
  * Requires by


Connecting Business Capabilities with Business Contexts:
  * Requires
  * Requires by
  * Business Capability to Business Contexts
